@@ -199,7 +199,7 @@ static guint signals[LAST_SIGNAL] = { 0 };
 #define ACCOUNT_REGEX_ICQ      "^"ICQ_USER_NAME"$"
 #define ACCOUNT_REGEX_IRC      "^"IRC_NICK_NAME"$"
 #define USERNAME_REGEX_IRC     "^"IRC_USER_NAME"$"
-#define ACCOUNT_REGEX_JABBER   "^"JABBER_USER_NAME"@"HOST"$"
+#define ACCOUNT_REGEX_JABBER   "^"JABBER_USER_NAME"@[^@/]+"
 #define ACCOUNT_REGEX_MSN      "^"MSN_USER_NAME"@"HOST"$"
 #define ACCOUNT_REGEX_YAHOO    "^"YAHOO_USER_NAME"$"
 
@@ -694,6 +694,8 @@ account_widget_generic_format_param_name (const gchar *param_name)
   gchar *p;
   static GHashTable *translated_params = NULL;
 
+  g_return_val_if_fail (param_name != NULL, NULL);
+
   if (G_UNLIKELY (translated_params == NULL))
     translated_params = build_translated_params ();
 
