@@ -81,6 +81,48 @@ tpy_svc_call_content_codec_offer_return_from_reject (DBusGMethodInvocation *cont
 }
 
 
+typedef struct _TpySvcCallContentInterfaceAudioControl TpySvcCallContentInterfaceAudioControl;
+
+typedef struct _TpySvcCallContentInterfaceAudioControlClass TpySvcCallContentInterfaceAudioControlClass;
+
+GType tpy_svc_call_content_interface_audio_control_get_type (void);
+#define TPY_TYPE_SVC_CALL_CONTENT_INTERFACE_AUDIO_CONTROL \
+  (tpy_svc_call_content_interface_audio_control_get_type ())
+#define TPY_SVC_CALL_CONTENT_INTERFACE_AUDIO_CONTROL(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TPY_TYPE_SVC_CALL_CONTENT_INTERFACE_AUDIO_CONTROL, TpySvcCallContentInterfaceAudioControl))
+#define TPY_IS_SVC_CALL_CONTENT_INTERFACE_AUDIO_CONTROL(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TPY_TYPE_SVC_CALL_CONTENT_INTERFACE_AUDIO_CONTROL))
+#define TPY_SVC_CALL_CONTENT_INTERFACE_AUDIO_CONTROL_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TPY_TYPE_SVC_CALL_CONTENT_INTERFACE_AUDIO_CONTROL, TpySvcCallContentInterfaceAudioControlClass))
+
+
+typedef void (*tpy_svc_call_content_interface_audio_control_report_input_volume_impl) (TpySvcCallContentInterfaceAudioControl *self,
+    gint in_Volume,
+    DBusGMethodInvocation *context);
+void tpy_svc_call_content_interface_audio_control_implement_report_input_volume (TpySvcCallContentInterfaceAudioControlClass *klass, tpy_svc_call_content_interface_audio_control_report_input_volume_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tpy_svc_call_content_interface_audio_control_return_from_report_input_volume (DBusGMethodInvocation *context);
+static inline void
+tpy_svc_call_content_interface_audio_control_return_from_report_input_volume (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tpy_svc_call_content_interface_audio_control_report_output_volume_impl) (TpySvcCallContentInterfaceAudioControl *self,
+    gint in_Volume,
+    DBusGMethodInvocation *context);
+void tpy_svc_call_content_interface_audio_control_implement_report_output_volume (TpySvcCallContentInterfaceAudioControlClass *klass, tpy_svc_call_content_interface_audio_control_report_output_volume_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tpy_svc_call_content_interface_audio_control_return_from_report_output_volume (DBusGMethodInvocation *context);
+static inline void
+tpy_svc_call_content_interface_audio_control_return_from_report_output_volume (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+
 typedef struct _TpySvcCallContentInterfaceMedia TpySvcCallContentInterfaceMedia;
 
 typedef struct _TpySvcCallContentInterfaceMediaClass TpySvcCallContentInterfaceMediaClass;
